@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package IO::Socket::Timeout;
-$IO::Socket::Timeout::VERSION = '0.28';
+$IO::Socket::Timeout::VERSION = '0.29';
 use strict;
 use warnings;
 use Config;
@@ -75,12 +75,13 @@ BEGIN {
         my $_prevent_deep_recursion;
         *CORE::GLOBAL::sysread = sub {
             my $args_count = scalar(@_);
-            $_prevent_deep_recursion || ! (PerlIO::via::Timeout->_fh2prop($_[0]) || {})->{timeout_enabled}
+               $_prevent_deep_recursion
+            || ! PerlIO::via::Timeout::has_timeout_layer($_[0])
+            || ! PerlIO::via::Timeout::timeout_enabled($_[0])
               and return (  $args_count == 4 ? CORE::sysread($_[0], $_[1], $_[2], $_[3])
                           :                    CORE::sysread($_[0], $_[1], $_[2])
                          );
             $_prevent_deep_recursion = 1;
-            require PerlIO::via::Timeout;
             my $ret_val = PerlIO::via::Timeout->READ($_[1], $_[2], $_[0]);
             $_prevent_deep_recursion = 0;
             return $ret_val;
@@ -99,13 +100,14 @@ BEGIN {
         my $_prevent_deep_recursion;
         *CORE::GLOBAL::syswrite = sub {
             my $args_count = scalar(@_);
-            $_prevent_deep_recursion || ! (PerlIO::via::Timeout->_fh2prop($_[0]) || {})->{timeout_enabled}
+               $_prevent_deep_recursion
+            || ! PerlIO::via::Timeout::has_timeout_layer($_[0])
+            || ! PerlIO::via::Timeout::timeout_enabled($_[0])
               and return(   $args_count == 4 ? CORE::syswrite($_[0], $_[1], $_[2], $_[3])
                           : $args_count == 3 ? CORE::syswrite($_[0], $_[1], $_[2])
                           :                    CORE::syswrite($_[0], $_[1])
                         );
             $_prevent_deep_recursion = 1;
-            require PerlIO::via::Timeout;
             my $ret_val = PerlIO::via::Timeout->WRITE($_[1], $_[0]);
             $_prevent_deep_recursion = 0;
             return $ret_val;
@@ -114,7 +116,7 @@ BEGIN {
 }
 
 package IO::Socket::Timeout::Role::SetSockOpt;
-$IO::Socket::Timeout::Role::SetSockOpt::VERSION = '0.28';
+$IO::Socket::Timeout::Role::SetSockOpt::VERSION = '0.29';
 use Carp;
 use Socket;
 
@@ -172,7 +174,7 @@ sub _set_sock_opt {
 }
 
 package IO::Socket::Timeout::Role::PerlIO;
-$IO::Socket::Timeout::Role::PerlIO::VERSION = '0.28';
+$IO::Socket::Timeout::Role::PerlIO::VERSION = '0.29';
 use PerlIO::via::Timeout;
 
 sub read_timeout    { goto &PerlIO::via::Timeout::read_timeout    }
@@ -195,7 +197,7 @@ IO::Socket::Timeout - IO::Socket with read/write timeout
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -324,9 +326,10 @@ internally, composed classes needed gets created and loaded at compile time.
 
 =head2 PERL_IO_SOCKET_TIMEOUT_FORCE_SELECT
 
-This module implements timeouts using one of two strategy. If possible (if the
-operating system is linux or mac), it uses C<setsockopt()> to set read / write
-timeouts. Otherwise it uses C<select()> before performing socket operations.
+This module implements timeouts using one of two strategies. If possible (if
+the operating system is linux, freebsd or mac), it uses C<setsockopt()> to set
+read / write timeouts. Otherwise it uses C<select()> before performing socket
+operations.
 
 To force the use of C<select()>, you can set
 PERL_IO_SOCKET_TIMEOUT_FORCE_SELECT to a true value at compile time (typically
